#
# spec file for package maven-doxia-sitetools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-doxia-sitetools
Version:        2.0.0
Release:        1.2
Summary:        Doxia content generation framework
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/doxia/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.tar.xz
Patch1:         0001-Remove-dependency-on-velocity-tools.patch
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-doxia-core
BuildRequires:  maven-doxia-module-xhtml5
BuildRequires:  maven-doxia-sink-api
BuildRequires:  maven-lib
BuildRequires:  maven-reporting-api
BuildRequires:  maven-resolver-api
BuildRequires:  modello
BuildRequires:  plexus-i18n
BuildRequires:  plexus-interpolation
BuildRequires:  plexus-metadata-generator
BuildRequires:  plexus-utils
BuildRequires:  plexus-velocity
BuildRequires:  plexus-xml
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  velocity-engine-core
BuildArch:      noarch

%description
Doxia is a content generation framework which aims to provide its
users with powerful techniques for generating static and dynamic
content. Doxia can be used to generate static sites in addition to
being incorporated into dynamic content generation systems like blogs,
wikis and content management systems.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q -a1
%patch -P 1 -p1

%pom_remove_dep -r :velocity-tools-generic

%build
mkdir -p lib
build-jar-repository -s lib \
    apache-commons-lang3 \
    atinject \
    commons-io \
    maven-doxia/doxia-core \
    maven-doxia/doxia-module-xhtml5 \
    maven-doxia/doxia-sink-api \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven-reporting-api/maven-reporting-api \
    maven-resolver/maven-resolver-api \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus-i18n/plexus-i18n \
    plexus/interpolation \
    plexus/utils \
    plexus-velocity/plexus-velocity \
    plexus/xml \
    slf4j/api \
    velocity-engine/velocity-engine-core

ant package javadoc

%install
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
for i in \
    doxia-site-model \
    doxia-skin-model \
    doxia-site-renderer \
    doxia-integration-tools; do
  install -pm 0644 ${i}/target/${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${i}.jar
  %{mvn_install_pom} ${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/${i}.pom
  %add_maven_depmap %{name}/${i}.pom %{name}/${i}.jar -f ${i}
  if [ -d ${i}/target/site/apidocs ]; then
    cp -r ${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
  fi
done
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-doxia-integration-tools -f .mfiles-doxia-site-model -f .mfiles-doxia-site-renderer -f .mfiles-doxia-skin-model

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Mon Oct  7 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.0.0
  * Bug
    + DOXIASITETOOLS-251: Plexus to Sisu migration misses Singleton
    annotation
    + DOXIASITETOOLS-263: Don't inject a default decoration model
    when inheritance is at play
    + DOXIASITETOOLS-266: Don't create anchors behind the user's
    back
    + DOXIASITETOOLS-299: Site descriptor interpolation does not
    properly escape reserved XML chars
    + DOXIASITETOOLS-305: Removal of 0-byte site descriptors from
    the local repo does not put remote repos into consideration
  * New Feature
    + DOXIASITETOOLS-238: Pass input file name as reference to
    parser
    + DOXIASITETOOLS-291: Add timezone field to site descriptor
    PublishDate object and pass onto Velocity tools context
    + DOXIASITETOOLS-324: Allow configuration of parser per markup
  * Improvement
    + DOXIASITETOOLS-253: Clarify "border", "width" and "height" for
    Banner and LinkItem
    + DOXIASITETOOLS-257: Require a skin if a site descriptor
    (site.xml) has been provided
    + DOXIASITETOOLS-268: Don't open version resource file on every
    call to render
    + DOXIASITETOOLS-271: Overhaul locale support (make Locale#ROOT
    instead of Locale#ENGLISH default and use full locale)
    + DOXIASITETOOLS-278: Remove menu items link in the sidebar to
    submodule that do not generate any site in the same build
    + DOXIASITETOOLS-293: Remove menu items link in the sidebar to
    submodule that are not present in the same build (reactor)
    + DOXIASITETOOLS-294: Replace legacy artifact resolution with
    Maven Resolver
    + DOXIASITETOOLS-300: Don't populate Velocity context with XML
    entities
    + DOXIASITETOOLS-301: Automatically remove the 0-byte site
    descriptors from the local repo
    + DOXIASITETOOLS-302: Harmonize path separator in
    DocumentRenderingContext
    + DOXIASITETOOLS-332: Create anchors for indexable entries
    automatically
    + DOXIASITETOOLS-334: Pass project relative source path to
    Parser.parse(...) as reference argument
    + DOXIASITETOOLS-336: Make SiteRenderingContext#siteDirectories
    editable aware
    + DOXIASITETOOLS-340: Rearrange title order in Velocity context
    + DOXIASITETOOLS-344: Improve performance of case-sensitive file
    key checking
    + DOXIASITETOOLS-348: Extend site descriptor to enforce a parent
    + DOXIASITETOOLS-349: Remove plexus-component-metadata plugin
  * Wish
    + DOXIASITETOOLS-174: rename site.xml root tag from "project" to
    "site"
  * Task
    + DOXIASITETOOLS-156: Fail if deprecated ${reports},
    ${parentProject} or ${modules} is found
    + DOXIASITETOOLS-167: Replace deprecated Maven 2
    MavenProjectBuilder with Maven 3 ProjectBuilder
    + DOXIASITETOOLS-239: Remove Doxia Sitetools Doc Renderer
    + DOXIASITETOOLS-241: Replace Plexus Container Default with Sisu
    Plexus Shim
    + DOXIASITETOOLS-242: Remove all deprecated code
    + DOXIASITETOOLS-244: Clean up exceptions and log messages
    + DOXIASITETOOLS-245: Upgrade to Java 8
    + DOXIASITETOOLS-247: Replace Plexus Annotations with Java
    Inject along with JUnit 5
    + DOXIASITETOOLS-254: Clarify inconsistencies in Doxia site
    model
    + DOXIASITETOOLS-258: Don't inject bannerLeft is none is set
    + DOXIASITETOOLS-259: Deprecate Google-related site descriptor
    properties
    + DOXIASITETOOLS-264: Remove usage of default skin during
    testing
    + DOXIASITETOOLS-265: Drop MiscVerifier
    + DOXIASITETOOLS-270: Remove internal (pseudo) skin and use
    Maven Fluido Skin by default
    + DOXIASITETOOLS-272: Remove support for Maven 1.x style site
    directory layout
    + DOXIASITETOOLS-281: Deprecate SiteTool#getParentProject() in
    favor of MavenProject#getParent()
    + DOXIASITETOOLS-282: Deprecate support for Maven 1.x style site
    directory layout
    + DOXIASITETOOLS-285: Deprecate
    SiteRenderingContext#defaultWindowTitle in favor of
    SiteRenderingContext#defaultTitle
    + DOXIASITETOOLS-287: Remove Google-related site descriptor
    properties
    + DOXIASITETOOLS-289: Remove SiteTool#getParentProject()
    + DOXIASITETOOLS-290: Remove
    SiteRenderingContext#defaultWindowTitle
    + DOXIASITETOOLS-295: Rename o.a.m.doxia.siterenderer.Renderer
    to o.a.m.doxia.siterenderer.SiteRenderer
    + DOXIASITETOOLS-296: Rename
    o.a.m.doxia.siterenderer.RenderingContext to
    o.a.m.doxia.siterenderer.DocumentRenderingContext
    + DOXIASITETOOLS-298: Rename doxia-decoration-model to
    doxia-site-model
    + DOXIASITETOOLS-303: Implement workaround for
    MNG-7758/MRESOLVER-335
    + DOXIASITETOOLS-306: Clean up and simplify thrown exceptions
    + DOXIASITETOOLS-309: Add resource bundle property "External
    Links" to site-renderer.properties
    + DOXIASITETOOLS-310: Add resource bundle property "Edit" to
    site-renderer.properties
    + DOXIASITETOOLS-311: Rework and simplify the site model
    + DOXIASITETOOLS-319: Improve DocumentRenderer
    interface/DocumentRenderingContext class API
- Modified patch:
  * 0002-Remove-dependency-on-velocity-tools.patch ->
    0001-Remove-dependency-on-velocity-tools.patch
    + rediff
* Sun Sep 29 2024 Fridrich Strba <fstrba@suse.com>
- Don't build/distribute unused doxia-doc-renderer
* Mon Jun 10 2024 Fridrich Strba <fstrba@suse.com>
- Use plexus-metadata-generator executable directly to simplify
  build classpath
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep 23 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.11.1
  * Bug
    + DOXIASITETOOLS-221:  CLIRR can't find previous version
  * Improvement
    + DOXIASITETOOLS-228:  Remove all &#xA0; in
    default-site-macros.vm and replace by a space
    + DOXIASITETOOLS-234:  improve documentation on site.xml
    inheritance vs interpolation
  * Task
    + DOXIASITETOOLS-236:  Deprecate Doxia Sitetools Doc Renderer
  * Dependency upgrade
    + DOXIASITETOOLS-219:  fix javadoc issues with JDK 8 when
    generating documentation
    + DOXIASITETOOLS-223:  wrong coordinates for jai_core: hyphen
    should be underscore
    + DOXIASITETOOLS-226:  Use latest JUnit version 4.13.2
    + DOXIASITETOOLS-231:  Upgrade Plexus Utils to 3.3.0
    + DOXIASITETOOLS-232:  Upgrade Plexus Interpolation to 1.26
    + DOXIASITETOOLS-233:  Upgrade Maven Doxia to 1.10
    + DOXIASITETOOLS-237:  Upgrade Maven Doxia to 1.11.1
- Modified patch:
  * 0002-Remove-dependency-on-velocity-tools.patch
    + rediff to changes context
- Removed patch:
  * 0001-Port-to-plexus-utils-3.0.24.patch
    + not needed with this version
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 any more
* Wed Mar 11 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.2
- Modified patches:
  * 0001-Port-to-plexus-utils-3.0.24.patch
  * 0002-Remove-dependency-on-velocity-tools.patch
    + fix incorrect line end
* Thu Mar 28 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-doxia-sitetools 1.7.5
- Generate and customize ant build files
